@@ -1,16 +1,14 @@
+import atexit
 import os
-
-from packaging import version
 import subprocess as subp
 import time
-import yaml
 from http.client import RemoteDisconnected
 
-import atexit
-import pynetbox
 import pytest
 import requests
+import yaml
 
+import pynetbox
 
 DOCKER_PROJECT_PREFIX = "pytest_pynetbox"
 
@@ -28,14 +26,12 @@ def get_netbox_docker_version_tag(netbox_version):
     """
     major, minor = netbox_version.major, netbox_version.minor
 
-    if (major, minor) == (2, 10):
-        tag = "1.0.1"
-    elif (major, minor) == (2, 9):
-        tag = "0.26.2"
-    elif (major, minor) == (2, 8):
-        tag = "0.24.1"
-    elif (major, minor) == (2, 7):
-        tag = "0.24.0"
+    if (major, minor) == (4, 2):
+        tag = "3.2.1"
+    elif (major, minor) == (4, 3):
+        tag = "3.3.0"
+    elif (major, minor) == (4, 4):
+        tag = "3.4.2"
     else:
         raise NotImplementedError(
             "Version %s is not currently supported" % netbox_version
@@ -55,7 +51,7 @@ def git_toplevel():
     try:
         subp.check_call(["which", "git"])
     except subp.CalledProcessError:
-        pytest.skip(msg="git executable was not found on the host")
+        pytest.skip(reason="git executable was not found on the host")
     return (
         subp.check_output(["git", "rev-parse", "--show-toplevel"])
         .decode("utf-8")
@@ -80,10 +76,11 @@ def netbox_docker_repo_dirpaths(pytestconfig, git_toplevel):
     try:
         subp.check_call(["which", "docker"])
     except subp.CalledProcessError:
-        pytest.skip(msg="docker executable was not found on the host")
+        pytest.skip(reason="docker executable was not found on the host")
     netbox_versions_by_repo_dirpaths = {}
     for netbox_version in pytestconfig.option.netbox_versions:
         repo_version_tag = get_netbox_docker_version_tag(netbox_version=netbox_version)
+        print("top: ", git_toplevel)
         repo_fpath = os.path.join(
             git_toplevel, ".netbox-docker-%s" % str(repo_version_tag)
         )
@@ -231,9 +228,12 @@ def docker_compose_file(pytestconfig, netbox_docker_repo_dirpaths):
                 DOCKER_PROJECT_PREFIX,
                 docker_netbox_version,
             )
-            compose_data["networks"] = {
-                docker_network_name: {"name": docker_network_name,}
-            }
+            compose_data["networks"] = {docker_network_name: {}}
+            # https://docs.docker.com/compose/compose-file/compose-file-v3/#network-configuration-reference
+            if "version" not in compose_data or compose_data["version"] >= "3.5":
+                compose_data["networks"][docker_network_name][
+                    "name"
+                ] = docker_network_name
 
             # prepend the netbox version to each of the service names and anything else
             # needed to make the continers unique to the netbox version
@@ -251,6 +251,28 @@ def docker_compose_file(pytestconfig, netbox_docker_repo_dirpaths):
                         "netboxcommunity/netbox:v%s" % netbox_version
                     )
 
+                    new_services[new_service_name]["environment"] = {
+                        "SKIP_SUPERUSER": "false",
+                        "SUPERUSER_API_TOKEN": "0123456789abcdef0123456789abcdef01234567",
+                        "SUPERUSER_EMAIL": "admin@example.com",
+                        "SUPERUSER_NAME": "admin",
+                        "SUPERUSER_PASSWORD": "admin",
+                    }
+
+                if service_name == "netbox":
+                    # ensure the netbox container listens on a random port
+                    new_services[new_service_name]["ports"] = ["8080"]
+
+                    # Increase health check timeouts for GitHub Actions runners
+                    # which may have more resource constraints
+                    new_services[new_service_name]["healthcheck"] = {
+                        "test": "curl -f http://localhost:8080/login/ || exit 1",
+                        "start_period": "180s",  # Increased from 90s
+                        "timeout": "10s",  # Increased from 3s
+                        "interval": "15s",
+                        "retries": 5,
+                    }
+
                 # set the network and an alias to the proper short name of the container
                 # within that network
                 new_services[new_service_name]["networks"] = {
@@ -265,7 +287,10 @@ def docker_compose_file(pytestconfig, netbox_docker_repo_dirpaths):
                     ]:
                         new_service_dependencies.append(
                             "netbox_v%s_%s"
-                            % (docker_netbox_version, dependent_service_name,)
+                            % (
+                                docker_netbox_version,
+                                dependent_service_name,
+                            )
                         )
                     new_services[new_service_name][
                         "depends_on"
@@ -311,12 +336,17 @@ def docker_compose_file(pytestconfig, netbox_docker_repo_dirpaths):
             for volume_name, volume_config in compose_data["volumes"].items():
                 new_volumes[
                     "%s_v%s_%s"
-                    % (DOCKER_PROJECT_PREFIX, docker_netbox_version, volume_name,)
+                    % (
+                        DOCKER_PROJECT_PREFIX,
+                        docker_netbox_version,
+                        volume_name,
+                    )
                 ] = volume_config
             compose_data["volumes"] = new_volumes
 
             compose_output_fpath = os.path.join(
-                netbox_docker_repo_dirpath, "docker-compose-v%s.yml" % netbox_version,
+                netbox_docker_repo_dirpath,
+                "docker-compose-v%s.yml" % netbox_version,
             )
             with open(compose_output_fpath, "w") as fdesc:
                 fdesc.write(yaml.dump(compose_data))
@@ -332,7 +362,7 @@ def docker_compose_file(pytestconfig, netbox_docker_repo_dirpaths):
 
 
 def netbox_is_responsive(url):
-    """Chack if the HTTP service is up and responsive."""
+    """Check if the HTTP service is up and responsive."""
     try:
         response = requests.get(url)
         if response.status_code == 200:
@@ -358,7 +388,10 @@ def id_netbox_service(fixture_value):
 
 @pytest.fixture(scope="session")
 def docker_netbox_service(
-    pytestconfig, docker_ip, docker_services, request,
+    pytestconfig,
+    docker_ip,
+    docker_services,
+    request,
 ):
     """Get the netbox service to test against.
 
@@ -368,14 +401,10 @@ def docker_netbox_service(
     """
     netbox_integration_version = request.param
 
-    if netbox_integration_version >= version.Version("2.10"):
-        netbox_service_name = "netbox_v%s_netbox" % str(
-            netbox_integration_version
-        ).replace(".", "_")
-    else:
-        netbox_service_name = "netbox_v%s_nginx" % str(
-            netbox_integration_version
-        ).replace(".", "_")
+    netbox_service_name = "netbox_v%s_netbox" % str(netbox_integration_version).replace(
+        ".", "_"
+    )
+
     netbox_service_port = 8080
     try:
         # `port_for` takes a container port and returns the corresponding host port
@@ -459,12 +488,14 @@ def device_type(api, manufacturer):
 
 
 @pytest.fixture(scope="session")
-def device_role(api):
-    device_role = api.dcim.device_roles.create(
-        name="test-device-role", slug="test-device-role", color="000000",
+def role(api):
+    role = api.dcim.device_roles.create(
+        name="test-device-role",
+        slug="test-device-role",
+        color="000000",
     )
-    yield device_role
-    device_role.delete()
+    yield role
+    role.delete()
 
 
 def pytest_generate_tests(metafunc):
